@@ -38,4 +38,5 @@
 #' @importFrom dplyr first last n
 #' @useDynLib stplanr
 NULL
-utils::globalVariables(c(".", "n", "matchingID"))
+utils::globalVariables(c(".", "n"))
+
